PROC IMPORT DATAFILE = "U:\Stata_long\aspart.xlsx"
DBMS=xlsx REPLACE OUT = one;
GETNAMES=YES;
PROC MEANS;

PROC FORMAT;
VALUE Dgrp 0='Placebo' 1='Aspartame';

PROC SORT; BY DrugAsp;
/* summary stats for Headache by DrugAsp groups */
PROC MEANS; VAR Headache; BY DrugAsp; FORMAT DrugAsp Dgrp.;

/* Histogram of Headache */
PROC SGPLOT;
VBAR Headache;

/* Box-plots of Headache by DrugAsp groups */
PROC SGPLOT;
VBOX Headache / GROUP=DrugAsp;
FORMAT DrugAsp Dgrp.;
RUN;

/* histogram of NTDays */
PROC SGPLOT;
VBAR NTDays;
RUN;

/* random intercept Poisson model */
PROC GLIMMIX METHOD=QUAD;
CLASS id; 
MODEL Headache = Period1 Period2 Period3 Period4 DrugAsp / LINK=LOG DIST=POISSON;
RANDOM INT / SUBJECT=id;
COVTEST 'test of random intercept var' GLM; 
RUN;

/* random intercept Poisson model with offset */
PROC GLIMMIX METHOD=QUAD;
CLASS id; 
logNTDays = log(NTDays);
MODEL Headache = Period1 Period2 Period3 Period4 DrugAsp / LINK=LOG S DIST=POISSON OFFSET=logNTDays;
RANDOM INT / SUBJECT=id S;
ODS OUTPUT SOLUTIONR=ebest;
COVTEST 'test of random intercept var' GLM; 
RUN;

/* print out the estimated random effects */
PROC PRINT DATA=ebest;
RUN;

DATA ebestci; SET ebest;
lo = Estimate-PROBIT(.975)*StdErrPred;
hi = Estimate+PROBIT(.975)*StdErrPred;
RUN;

/* standard error plot with estimated random effects */
PROC SORT; BY Estimate;
PROC SGPLOT DATA=ebestci;
SCATTER X=Subject Y=Estimate / YERRORLOWER=lo YERRORUPPER=hi;
RUN;

/* random intercept & DrugAsp Poisson model with offset */
PROC GLIMMIX METHOD=QUAD DATA=one;
CLASS id; 
logNTDays = log(NTDays);
MODEL Headache = Period1 Period2 Period3 Period4 DrugAsp / LINK=LOG S DIST=POISSON OFFSET=logNTDays;
RANDOM INT DrugAsp / SUBJECT=id TYPE=UN G GCORR S;
ODS OUTPUT SOLUTIONR=ebest2;
COVTEST 'test of random effects' GLM;
COVTEST 'test of random slope' . 0 0;
RUN;

/* print out the estimated random effects */
PROC PRINT DATA=ebest2;
RUN;

/* select only the random slopes */
DATA ebest2ci; SET ebest2; if Effect = "DrugAsp";
lo = Estimate-PROBIT(.975)*StdErrPred;
hi = Estimate+PROBIT(.975)*StdErrPred;
RUN;

/* standard error plot with estimated random effects */
PROC SORT; BY Estimate;
PROC SGPLOT DATA=ebest2ci;
SCATTER X=Subject Y=Estimate / YERRORLOWER=lo YERRORUPPER=hi;
REFLINE 0 /AXIS=Y; 
RUN;


/* random intercept Negative Binomial model with offset */
PROC GLIMMIX METHOD=QUAD DATA=one;
CLASS id; 
logNTDays = log(NTDays);
MODEL Headache = Period1 Period2 Period3 Period4 DrugAsp / LINK=LOG S DIST=NEGBINOMIAL OFFSET=logNTDays;
RANDOM INT / SUBJECT=id;
COVTEST 'test of random intercept var' GLM; 
RUN;





